@@ -248,7 +248,7 @@ static QString doContent(QDomElement elem, int startingPos, ContentEditingData*
  * - deletes content, or
  * - inserts content
  */
-static QString content(QDomElement elem, ContentEditingData* data = 0)
+static QString content(QDomElement elem, ContentEditingData* data = nullptr)
 {
     return doContent(elem, 0, data);
 }
